@@ -10,6 +10,7 @@
 #define MY_EVP_PKEY_get0_RSA EVP_PKEY_get0_RSA
 #define MY_EVP_PKEY_get0_DSA EVP_PKEY_get0_DSA
 #define MY_EVP_PKEY_get0_EC_KEY EVP_PKEY_get0_EC_KEY
+#define MY_X509_STORE_CTX_get0_cert X509_STORE_CTX_get0_cert
 #define MY_RSA_set0_key RSA_set0_key
 #define MY_RSA_set0_factors RSA_set0_factors
 #define MY_RSA_set0_crt_params RSA_set0_crt_params
@@ -23,9 +24,9 @@
 #define MY_X509_get0_signature X509_get0_signature
 #define MY_ECDSA_SIG_get0 ECDSA_SIG_get0
 #define MY_ECDSA_SIG_set0 ECDSA_SIG_set0
-
 #else
 
+X509 *MY_X509_STORE_CTX_get0_cert(X509_STORE_CTX *store);
 RSA *MY_EVP_PKEY_get0_RSA(EVP_PKEY *pkey);
 DSA *MY_EVP_PKEY_get0_DSA(EVP_PKEY *pkey);
 EC_KEY *MY_EVP_PKEY_get0_EC_KEY(EVP_PKEY *pkey);
