@@ -6,12 +6,9 @@
 
 SEXP R_RAND_bytes(SEXP n) {
   int length = asInteger(n);
-  if(length <= 0)
-    return allocVector(RAWSXP, 0);
-  unsigned char buf[length];
-  bail(RAND_bytes(buf, length));
   SEXP out = PROTECT(allocVector(RAWSXP, length));
-  memcpy(RAW(out), buf, length);
+  if(length > 0)
+    bail(RAND_bytes(RAW(out), length));
   UNPROTECT(1);
   return out;
 }
